/*
     This file is part of GNUnet.
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

#include "config.h"
#include "gnettypes.h"
#include "util/tcpio.h"
#include <netinet/in.h>

/**
 * Obtain a return value from a remote call from
 * TCP.
 * @param sock the TCP socket
 * @param ret the return value from TCP
 * @return SYSERR on error, OK if the return value was
 *         read successfully
 **/
int readTCPResult(GNUNET_TCP_SOCKET * sock,
		  int * ret) {
  TCP_SOCKET_BUFFER buf;
  TCP_Return_Value * rv;
  if (SYSERR == readFromSocket(sock,
			       &buf))
    return SYSERR;
  rv = (TCP_Return_Value*) &buf;
  if ( (ntohs(rv->header.size) != sizeof(TCP_Return_Value)) ||
       (ntohs(rv->header.tcpType) != TCP_RETURN_VALUE) )
    return SYSERR;
  *ret = ntohl(rv->return_value);
  return OK;
}

/**
 * Send a return value to the caller of a remote call via
 * TCP.
 * @param sock the TCP socket
 * @param ret the return value to send via TCP
 * @return SYSERR on error, OK if the return value was
 *         send successfully
 **/
int sendTCPResult(GNUNET_TCP_SOCKET * sock,
		  int ret) {
  TCP_Return_Value rv;
  
  rv.header.size = htons(sizeof(TCP_Return_Value));
  rv.header.tcpType = htons(TCP_RETURN_VALUE);
  rv.return_value = htonl(ret);
  return writeToSocket(sock,
		       (TCP_SOCKET_BUFFER*)&rv);
}

/* end of tcp_return.c */
